/****************************************************************************
** Meta object code from reading C++ file 'kdirnotify.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kio-6.29.0/src/core/kdirnotify.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kdirnotify.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25OrgKdeKDirNotifyInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeKDirNotifyInterface::qt_create_metaobjectdata<qt_meta_tag_ZN25OrgKdeKDirNotifyInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeKDirNotifyInterface",
        "FileRenamed",
        "",
        "src",
        "dst",
        "FileRenamedWithLocalPath",
        "dstPath",
        "FileMoved",
        "FilesAdded",
        "directory",
        "FilesChanged",
        "fileList",
        "FilesRemoved",
        "enteredDirectory",
        "url",
        "leftDirectory"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'FileRenamed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'FileRenamedWithLocalPath'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'FileMoved'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'FilesAdded'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'FilesChanged'
        QtMocHelpers::SignalData<void(const QStringList &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 11 },
        }}),
        // Signal 'FilesRemoved'
        QtMocHelpers::SignalData<void(const QStringList &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 11 },
        }}),
        // Signal 'enteredDirectory'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'leftDirectory'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeKDirNotifyInterface, qt_meta_tag_ZN25OrgKdeKDirNotifyInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeKDirNotifyInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25OrgKdeKDirNotifyInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25OrgKdeKDirNotifyInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25OrgKdeKDirNotifyInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeKDirNotifyInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeKDirNotifyInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->FileRenamed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->FileRenamedWithLocalPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->FileMoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->FilesAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->FilesChanged((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: _t->FilesRemoved((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 6: _t->enteredDirectory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->leftDirectory((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKDirNotifyInterface::*)(const QString & , const QString & )>(_a, &OrgKdeKDirNotifyInterface::FileRenamed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKDirNotifyInterface::*)(const QString & , const QString & , const QString & )>(_a, &OrgKdeKDirNotifyInterface::FileRenamedWithLocalPath, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKDirNotifyInterface::*)(const QString & , const QString & )>(_a, &OrgKdeKDirNotifyInterface::FileMoved, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKDirNotifyInterface::*)(const QString & )>(_a, &OrgKdeKDirNotifyInterface::FilesAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKDirNotifyInterface::*)(const QStringList & )>(_a, &OrgKdeKDirNotifyInterface::FilesChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKDirNotifyInterface::*)(const QStringList & )>(_a, &OrgKdeKDirNotifyInterface::FilesRemoved, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKDirNotifyInterface::*)(const QString & )>(_a, &OrgKdeKDirNotifyInterface::enteredDirectory, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKDirNotifyInterface::*)(const QString & )>(_a, &OrgKdeKDirNotifyInterface::leftDirectory, 7))
            return;
    }
}

const QMetaObject *OrgKdeKDirNotifyInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeKDirNotifyInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25OrgKdeKDirNotifyInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeKDirNotifyInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeKDirNotifyInterface::FileRenamed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void OrgKdeKDirNotifyInterface::FileRenamedWithLocalPath(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void OrgKdeKDirNotifyInterface::FileMoved(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void OrgKdeKDirNotifyInterface::FilesAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void OrgKdeKDirNotifyInterface::FilesChanged(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void OrgKdeKDirNotifyInterface::FilesRemoved(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void OrgKdeKDirNotifyInterface::enteredDirectory(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void OrgKdeKDirNotifyInterface::leftDirectory(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
