/****************************************************************************
** Meta object code from reading C++ file 'transferjob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kio-6.29.0/src/core/transferjob.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'transferjob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3KIO11TransferJobE_t {};
} // unnamed namespace

template <> constexpr inline auto KIO::TransferJob::qt_create_metaobjectdata<qt_meta_tag_ZN3KIO11TransferJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KIO::TransferJob",
        "data",
        "",
        "KIO::Job*",
        "job",
        "dataReq",
        "QByteArray&",
        "redirection",
        "QUrl",
        "url",
        "permanentRedirection",
        "fromUrl",
        "toUrl",
        "mimeTypeFound",
        "mimeType",
        "canResume",
        "KIO::filesize_t",
        "offset",
        "slotRedirection",
        "slotFinished",
        "slotData",
        "slotDataReq",
        "slotMimetype",
        "mimetype"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'data'
        QtMocHelpers::SignalData<void(KIO::Job *, const QByteArray &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QByteArray, 1 },
        }}),
        // Signal 'dataReq'
        QtMocHelpers::SignalData<void(KIO::Job *, QByteArray &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 6, 1 },
        }}),
        // Signal 'redirection'
        QtMocHelpers::SignalData<void(KIO::Job *, const QUrl &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 8, 9 },
        }}),
        // Signal 'permanentRedirection'
        QtMocHelpers::SignalData<void(KIO::Job *, const QUrl &, const QUrl &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 8, 11 }, { 0x80000000 | 8, 12 },
        }}),
        // Signal 'mimeTypeFound'
        QtMocHelpers::SignalData<void(KIO::Job *, const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::QString, 14 },
        }}),
        // Signal 'canResume'
        QtMocHelpers::SignalData<void(KIO::Job *, KIO::filesize_t)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 16, 17 },
        }}),
        // Slot 'slotRedirection'
        QtMocHelpers::SlotData<void(const QUrl &)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'slotFinished'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotData'
        QtMocHelpers::SlotData<void(const QByteArray &)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QByteArray, 1 },
        }}),
        // Slot 'slotDataReq'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotMimetype'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TransferJob, qt_meta_tag_ZN3KIO11TransferJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KIO::TransferJob::staticMetaObject = { {
    QMetaObject::SuperData::link<SimpleJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KIO11TransferJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KIO11TransferJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3KIO11TransferJobE_t>.metaTypes,
    nullptr
} };

void KIO::TransferJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TransferJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->data((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2]))); break;
        case 1: _t->dataReq((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray&>>(_a[2]))); break;
        case 2: _t->redirection((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 3: _t->permanentRedirection((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3]))); break;
        case 4: _t->mimeTypeFound((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->canResume((*reinterpret_cast<std::add_pointer_t<KIO::Job*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[2]))); break;
        case 6: _t->slotRedirection((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 7: _t->slotFinished(); break;
        case 8: _t->slotData((*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[1]))); break;
        case 9: _t->slotDataReq(); break;
        case 10: _t->slotMimetype((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KIO::Job* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TransferJob::*)(KIO::Job * , const QByteArray & )>(_a, &TransferJob::data, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferJob::*)(KIO::Job * , QByteArray & )>(_a, &TransferJob::dataReq, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferJob::*)(KIO::Job * , const QUrl & )>(_a, &TransferJob::redirection, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferJob::*)(KIO::Job * , const QUrl & , const QUrl & )>(_a, &TransferJob::permanentRedirection, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferJob::*)(KIO::Job * , const QString & )>(_a, &TransferJob::mimeTypeFound, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TransferJob::*)(KIO::Job * , KIO::filesize_t )>(_a, &TransferJob::canResume, 5))
            return;
    }
}

const QMetaObject *KIO::TransferJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KIO::TransferJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3KIO11TransferJobE_t>.strings))
        return static_cast<void*>(this);
    return SimpleJob::qt_metacast(_clname);
}

int KIO::TransferJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SimpleJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KIO::TransferJob::data(KIO::Job * _t1, const QByteArray & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KIO::TransferJob::dataReq(KIO::Job * _t1, QByteArray & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KIO::TransferJob::redirection(KIO::Job * _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KIO::TransferJob::permanentRedirection(KIO::Job * _t1, const QUrl & _t2, const QUrl & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void KIO::TransferJob::mimeTypeFound(KIO::Job * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void KIO::TransferJob::canResume(KIO::Job * _t1, KIO::filesize_t _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}
QT_WARNING_POP
