/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KIOExecd.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KIOEXECDADAPTOR_H
#define KIOEXECDADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "kioexecd.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.KIOExecd
 */
class KIOExecdAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.KIOExecd")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.KIOExecd\">\n"
"    <method name=\"watch\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"path\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"destUrl\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    KIOExecdAdaptor(KIOExecd *parent);
    ~KIOExecdAdaptor() override;

    inline KIOExecd *parent() const
    { return static_cast<KIOExecd *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void watch(const QString &path, const QString &destUrl);
Q_SIGNALS: // SIGNALS
};

#endif
