/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.kuiserver.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef KUISERVER_INTERFACE_H
#define KUISERVER_INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.kde.kuiserver
 */
class OrgKdeKuiserverInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.kuiserver"; }

public:
    OrgKdeKuiserverInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeKuiserverInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> emitJobUrlsChanged()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("emitJobUrlsChanged"), argumentList);
    }

    inline QDBusPendingReply<> registerService(const QString &service, const QString &objectPath)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(service) << QVariant::fromValue(objectPath);
        return asyncCallWithArgumentList(QStringLiteral("registerService"), argumentList);
    }

    inline QDBusPendingReply<bool> requiresJobTracker()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("requiresJobTracker"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void jobUrlsChanged(const QStringList &in0);
    void requiresJobTrackerChanged(bool in0);
};

namespace org {
  namespace kde {
    using kuiserver = ::OrgKdeKuiserverInterface;
  }
}

#endif
