/****************************************************************************
** Meta object code from reading C++ file 'knewfilemenu.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kio-6.29.0/src/filewidgets/knewfilemenu.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'knewfilemenu.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KNewFileMenuE_t {};
} // unnamed namespace

template <> constexpr inline auto KNewFileMenu::qt_create_metaobjectdata<qt_meta_tag_ZN12KNewFileMenuE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KNewFileMenu",
        "fileCreationStarted",
        "",
        "QUrl",
        "url",
        "fileCreated",
        "fileCreationRejected",
        "directoryCreationStarted",
        "directoryCreated",
        "directoryCreationRejected",
        "selectExistingDir",
        "checkUpToDate",
        "createDirectory",
        "createFile",
        "slotResult",
        "KJob*",
        "job"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'fileCreationStarted'
        QtMocHelpers::SignalData<void(const QUrl &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'fileCreated'
        QtMocHelpers::SignalData<void(const QUrl &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'fileCreationRejected'
        QtMocHelpers::SignalData<void(const QUrl &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'directoryCreationStarted'
        QtMocHelpers::SignalData<void(const QUrl &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'directoryCreated'
        QtMocHelpers::SignalData<void(const QUrl &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'directoryCreationRejected'
        QtMocHelpers::SignalData<void(const QUrl &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'selectExistingDir'
        QtMocHelpers::SignalData<void(const QUrl &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'checkUpToDate'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createDirectory'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createFile'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotResult'
        QtMocHelpers::SlotData<void(KJob *)>(14, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KNewFileMenu, qt_meta_tag_ZN12KNewFileMenuE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KNewFileMenu::staticMetaObject = { {
    QMetaObject::SuperData::link<KActionMenu::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KNewFileMenuE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KNewFileMenuE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KNewFileMenuE_t>.metaTypes,
    nullptr
} };

void KNewFileMenu::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KNewFileMenu *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->fileCreationStarted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 1: _t->fileCreated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 2: _t->fileCreationRejected((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 3: _t->directoryCreationStarted((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->directoryCreated((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 5: _t->directoryCreationRejected((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 6: _t->selectExistingDir((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 7: _t->checkUpToDate(); break;
        case 8: _t->createDirectory(); break;
        case 9: _t->createFile(); break;
        case 10: _t->slotResult((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KNewFileMenu::*)(const QUrl & )>(_a, &KNewFileMenu::fileCreationStarted, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNewFileMenu::*)(const QUrl & )>(_a, &KNewFileMenu::fileCreated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNewFileMenu::*)(const QUrl & )>(_a, &KNewFileMenu::fileCreationRejected, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNewFileMenu::*)(const QUrl & )>(_a, &KNewFileMenu::directoryCreationStarted, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNewFileMenu::*)(const QUrl & )>(_a, &KNewFileMenu::directoryCreated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNewFileMenu::*)(const QUrl & )>(_a, &KNewFileMenu::directoryCreationRejected, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KNewFileMenu::*)(const QUrl & )>(_a, &KNewFileMenu::selectExistingDir, 6))
            return;
    }
}

const QMetaObject *KNewFileMenu::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KNewFileMenu::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KNewFileMenuE_t>.strings))
        return static_cast<void*>(this);
    return KActionMenu::qt_metacast(_clname);
}

int KNewFileMenu::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KActionMenu::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KNewFileMenu::fileCreationStarted(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KNewFileMenu::fileCreated(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KNewFileMenu::fileCreationRejected(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KNewFileMenu::directoryCreationStarted(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KNewFileMenu::directoryCreated(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KNewFileMenu::directoryCreationRejected(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KNewFileMenu::selectExistingDir(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
